plone.app.event.vocabularies — plone.app.event 1.0dev documentation

### Navigation

- index
- modules |
- next |
- previous |
- plone.app.event 1.0dev documentation »
- plone.app.event API »

# plone.app.event.vocabularies

`plone.app.event.vocabularies.` `AvailableTimezones`(context)

  Vocabulary for available timezones, as set by in the controlpanel.

  This vocabulary is based on collective.elephantvocabulary. The reason is, that if timezones are used in events or in user’s settings and later retracted by the portal manager, they should still be usable for those objects but not selectable in forms.

  Note: after setting available_timezones, this vocabulary must be reinstantiated to reflect the changes.

`plone.app.event.vocabularies.` `SynchronizationStrategies`(context)

  Vocabulary for icalendar synchronization strategies.

`plone.app.event.vocabularies.` `Timezones`(context)

  Vocabulary for all timezones.

`plone.app.event.vocabularies.` `Weekdays`(context)

  Vocabulary for Weekdays.

  PLEASE NOTE: strftime %w interprets 0 as Sunday unlike the calendar module!

  > Note: Context is here a RecordProxy and cannot be used to get the site
  >   root. zope.i18n.translate seems not to respect the portal language.

### Navigation

- index
- modules |
- next |
- previous |
- plone.app.event 1.0dev documentation »
- plone.app.event API »